| Title: | Deductive Correction, Deductive Imputation, and Deterministic Correction |
|---|---|
| Description: | A collection of methods for automated data cleaning where all actions are logged. NOTE: active development has moved to the 'deductive' package. |
| Authors: | Mark van der Loo, Edwin de Jonge, and Sander Scholtus |
| Maintainer: | Mark van der Loo <[email protected]> |
| License: | GPL-3 |
| Version: | 1.4.1 |
| Built: | 2026-05-16 09:24:57 UTC |
| Source: | https://github.com/data-cleaning/deducorrect |